-- TowBall
-- Specialization for TowBall functionality
--
-- @author  Manuel Leithner &  Tobias F. (John Deere 6930)
-- @ Last Edit  30/01/2014
--

TowBall = {};

function TowBall.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Attachable, specializations);
end;

function TowBall:load(xmlFile)
	self.towBall = {};
	self.towBall.node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.towBall#index"));	
	setVisibility(self.towBall.node, false);
	self.towBall.nodePark = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.towBall#parkIndex"));	
	self.towBall.jointTransform = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.towBall#jointTransformIndex"));
	self.towBall.jointTransformBackUp = nil;
	
	self.vehicleJoint = nil;
	self.jointSearch = false;
end;

function TowBall:delete()
end;

function TowBall:readStream(streamId, connection)
end;

function TowBall:writeStream(streamId, connection)
end;

function TowBall:mouseEvent(posX, posY, isDown, isUp, button)
end;

function TowBall:keyEvent(unicode, sym, modifier, isDown)
end;

function TowBall:update(dt)
	if self.jointSearch then
		for k,v in pairs(self.attacherVehicle.attachedImplements) do
			if v.object == self then
				local joint = self.attacherVehicle.attacherJoints[v.jointDescIndex];
				self.vehicleJoint = joint;					
				unlink(self.towBall.node)
				setVisibility(self.towBall.node, true);
				link(joint.jointTransform, self.towBall.node);	
				self.towBall.jointTransformBackUp = joint.jointTransform;
				joint.jointTransform = self.towBall.jointTransform;
				setJointFrame(joint.jointIndex, 0, joint.jointTransform);
			end;
		end;
		self.jointSearch = false;
	end;	
end;

function TowBall:updateTick(dt)	
end;

function TowBall:draw()	
end;

function TowBall:onAttach(attacherVehicle)
	self.jointSearch = true;
end;

function TowBall:onDetach()
	if self.vehicleJoint ~= nil then		
		unlink(self.towBall.node);		
		self.vehicleJoint.jointTransform = self.towBall.jointTransformBackUp;
		self.towBall.jointTransformBackUp = nil;				
		setVisibility(self.towBall.node, false);
		link(self.towBall.nodePark, self.towBall.node);
	end;
	self.vehicleJoint = nil;
end;
