-- Wienhoff20200VTW
-- Specialisation for the Wienhoff 20200 VTW
--
-- @ Autor  Tobias F. (John Deere 6930)
-- @ Last Edit  25/02/2014
--
-- !!! NOTE: HARDSCRIPTED FOR WIENHOFF 20200 VTW !!!

Wienhoff20200VTW = {};

function Wienhoff20200VTW.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Attachable, specializations);
end;

function Wienhoff20200VTW:load(xmlFile)
    self.changeManureSpreaderState = SpecializationUtil.callSpecializationsFunction("changeManureSpreaderState");
	
	self.rightHoseArm = 2;
	self.rightHoseArmChanged = false;
	self.leftHoseArm = 1;
	self.leftHoseArmChanged = false;
	
	self.rightHosePark = 4;
	self.lastRightHoseParkHose = nil;
	self.rightHoseParkNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.hoseParkDummys#rightIndex"));
	self.rightHoseParkChanged = false;
	
	self.leftHosePark = 3;
	self.lastLeftHoseParkHose = nil;
	self.leftHoseParkNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.hoseParkDummys#leftIndex"));
	self.leftHoseParkChanged = false;
	
	self.searchHoseRefs = false;
	
	self:changeManureSpreaderState(self.allowsSpraying, true)
end;

function Wienhoff20200VTW:delete()
end;

function Wienhoff20200VTW:readStream(streamId, connection)
end;

function Wienhoff20200VTW:writeStream(streamId, connection)
end;

function Wienhoff20200VTW:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Wienhoff20200VTW:keyEvent(unicode, sym, modifier, isDown)
end;

function Wienhoff20200VTW:update(dt)

	if self.isClient then
		if self:getIsActiveForInput() and not self.isTurnedOn then
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA3) then
				self:changeManureSpreaderState(not self.allowsSpraying);
			end;
		end;
	end;

	if not self.searchHoseRefs then
		if self.hoseRef.refs[self.rightHoseArm] ~= nil then
			self.rightHoseArm = self.hoseRef.refs[self.rightHoseArm];
		end;
		if self.hoseRef.refs[self.leftHoseArm] ~= nil then
			self.leftHoseArm = self.hoseRef.refs[self.leftHoseArm];
		end;
		if self.hoseRef.refs[self.rightHosePark] ~= nil then
			self.rightHosePark = self.hoseRef.refs[self.rightHosePark];
		end;
		if self.hoseRef.refs[self.leftHosePark] ~= nil then
			self.leftHosePark = self.hoseRef.refs[self.leftHosePark];
		end;
		self:playAnimation("leftDockingStationArm", -1, nil);
		self:playAnimation("rightDockingStationArm", -1, nil);
		self.searchHoseRefs = true;
	end;
end;

function Wienhoff20200VTW:updateTick(dt)
	if self:getIsActive() then
		if self.isTurnedOn then
			self:unusualDirtIncrease(0.00005)
		end;
	end;
	if self.rightHoseArmChanged ~= self.rightHoseArm.isUsed then
		self.rightHoseArmChanged = self.rightHoseArm.isUsed;
		if self.rightHoseArm.isUsed then
			self:playAnimation("rightDockingStationArm", 1, nil);
		else
			self:playAnimation("rightDockingStationArm", -1, nil);
		end;
	end;
	if self.leftHoseArmChanged ~= self.leftHoseArm.isUsed then
		self.leftHoseArmChanged = self.leftHoseArm.isUsed;
		if self.leftHoseArm.isUsed then
			self:playAnimation("leftDockingStationArm", 1, nil);
		else
			self:playAnimation("leftDockingStationArm", -1, nil);
		end;
	end;
	
	if self.rightHoseParkChanged ~= self.rightHosePark.isUsed then
		self.rightHoseParkChanged = self.rightHosePark.isUsed;
		setVisibility(self.rightHoseParkNode, self.rightHosePark.isUsed);
		
		if self.lastRightHoseParkHose == nil then
			self.lastRightHoseParkHose = self.rightHosePark.hose.msh;
			setVisibility(self.lastRightHoseParkHose, false);
		else
			setVisibility(self.lastRightHoseParkHose, true);
			self.lastRightHoseParkHose = nil;		
		end;
	end;
	if self.leftHoseParkChanged ~= self.leftHosePark.isUsed then
		self.leftHoseParkChanged = self.leftHosePark.isUsed;
		setVisibility(self.leftHoseParkNode, self.leftHosePark.isUsed);
		
		if self.lastLeftHoseParkHose == nil then
			self.lastLeftHoseParkHose = self.leftHosePark.hose.msh;
			setVisibility(self.lastLeftHoseParkHose, false);
		else
			setVisibility(self.lastLeftHoseParkHose, true);
			self.lastLeftHoseParkHose = nil;		
		end;
	end;
end;

function Wienhoff20200VTW:draw()
	if self.isClient then
		if self:getIsActiveForInput(true) and not self.isTurnedOn then
			if self.allowsSpraying then
				g_currentMission:addHelpButtonText(g_i18n:getText("DISMOUNT_MANURESPREADER"), InputBinding.IMPLEMENT_EXTRA3);
			else
				g_currentMission:addHelpButtonText(g_i18n:getText("MOUNT_MANURESPREADER"), InputBinding.IMPLEMENT_EXTRA3);
			end;
		end;
	end
end;

function Wienhoff20200VTW:onAttach(attacherVehicle)
end;

function Wienhoff20200VTW:onDetach()
end;

function Wienhoff20200VTW:changeManureSpreaderState(state, noEventSend)
	ChangeManureSpreaderStateEvent.sendEvent(self, state, noEventSend);
	self.allowsSpraying = state;
	if state then
		self:playAnimation("changeManureSpreaderState", -1, nil);
	else
		self:playAnimation("changeManureSpreaderState", 1, nil);
	end;
end;
